import QtQuick 1.0
import com.meego 1.0

import MapWidget 1.0

Page {
  id: mapPage
  tools: mapTools

  // "theming"
  property int    _SIZE          : 64
  property int    _SPACE         : _SIZE/4

  // for some reason creating a map property alias doesn't work ...
  function getMapTypes()           { return map.getMapTypes(); }
  function getCurrentMapType()     { return map.getCurrentMapType(); }
  function setCurrentMapType(type) { map.setCurrentMapType(type); }

  Map {
    id: map
    anchors.fill: parent

    onEnableGpsButton:
      btnGps.enabled = on;

    onChangeGpsButton:
      btnGps.iconSource = image("map_overlay_gps" + (locked?"_follow":""))

    onZoomButtonStateChanged: {
      btnZoomIn.enabled = zoomIn; 
      btnZoomOut.enabled = zoomOut; 
    }
  }

  MapButton {
    id: btnZoomIn
    height: _SIZE; width: _SIZE
    x: _SPACE; y: _SPACE

    iconSource: image("map_overlay_zoom_in")

    enabled: map.zoomLevel < map.maximumZoomLevel;
    onClicked: map.zoomIn();
  }

  MapButton {
    id: btnGps
    height: _SIZE; width: _SIZE
    x: _SPACE; y: 2*_SPACE+_SIZE

    iconSource: image(map.gpsIsLocked()?"map_overlay_gps_follow":"map_overlay_gps")

    enabled: false
    onClicked: map.gpsFollow();
  }

  MapButton {
    id: btnZoomOut
    height: _SIZE; width: _SIZE
    x: _SPACE; y: 3*_SPACE+2*_SIZE

    iconSource: image("map_overlay_zoom_out")

    enabled: map.zoomLevel > map.minimumZoomLevel;
    onClicked: map.zoomOut();
  }

/*
  MapButton {
    id: btnDetail
    height: _SIZE; width: _SIZE
    x: parent.width-_SIZE-_SPACE; y: _SPACE

    iconSource: image("map_overlay_forward")
    enabled: false
  }
*/

  // Create a multi-selection dialog with a title and list elements to choose from.
  SelectionDialog {
     id: cacheProviderSelectionDialog
     titleText: qsTr("Select Cache Provider")
     selectedIndex: 1
     model: ListModel { id: elements }
     onAccepted: { var item=elements.get(selectedIndex).name; cacheProvider.value=item; System.setCacheProvider(item) }
  }

  function fillSelectionDialog() {
    var types = System.availableCacheproviders();
    for (var i = 0; i < types.length; i++) {
      var msg = { 'name': types[i] };
      cacheProviderSelectionDialog.model.append(msg);

      if(types[i] == System.currentCacheProvider())
        cacheProviderSelectionDialog.selectedIndex = i;
    }

    cacheProviderSelectionDialog.model.sync();   
  }

  Image {
    id: busyInd

    width: 128
    height: 128
    anchors.centerIn: parent

    source: image("busy")
    sourceSize.width: width
    sourceSize.height: height
    smooth: true

    RotationAnimation on rotation {
      loops: Animation.Infinite
      from: 0
      to: 360
      duration: 4000;
    }
  }  

  FileSelector { id: fileSelector; 
     onAccepted: console.log("Acepted: "+ selectedFile); }

  ToolBarLayout {
        id: mapTools

        ToolButton {
          text: "FileSelector"
          onClicked: fileSelector.open();
        }

        ToolComboButton {
          id: cacheProvider
	  text: qsTr("Cache Provider")
          value: System.currentCacheProvider()
          anchors.centerIn: parent
          onClicked: cacheProviderSelectionDialog.open(); 
        }

        ToolIcon {
            platformIconId: "toolbar-view-menu";
            anchors.right: parent.right
            onClicked: (mapMenu.status == DialogStatus.Closed) ? mapMenu.open() : mapMenu.close()
        }
    }

    Component.onCompleted: fillSelectionDialog();
}
