// http://library.developer.nokia.com/index.jsp?topic=/MeeGo_1.2_Harmattan_API/html/qt-components/qt-components-meego-buttoncolumn.html
// http://bugreports.qt.nokia.com/browse/QTCOMPONENTS-200 
// http://wiki.meego.com/Porting_Fremantle_Applications_to_Harmattan

import QtQuick 1.0
import com.meego 1.0

Page
{
  id: settingsPage
  anchors.margins: 10
  tools: backMenuTool

  property string mapType: mapPage.getCurrentMapType();
  property string mapServiceProvider: System.currentGeoServiceProvider();

  function setConfiguration() {
    if(mapType != mapPage.getCurrentMapType())
      mapPage.setCurrentMapType(mapType);

    if(mapServiceProvider != System.currentGeoServiceProvider()) 
      System.setGeoServiceProvider(mapServiceProvider);
  }

  function addButton(parent, name, selected, propertyName) {
    var button = Qt.createQmlObject("import com.meego 1.0; Button { checkable: true; text: '" + name + "'; checked: " + selected + "; onClicked: " + propertyName + "='" + name + "' }", parent);
  }

  function fillGroups() {
    var types = mapPage.getMapTypes();
    for (var i = 0; i < types.length; i++) 
      addButton(mapTypes, types[i], types[i] == mapType, "mapType");

    var types = System.availableGeoServiceProviders();
    for (var i = 0; i < types.length; i++) 
      addButton(mapServiceProviders, types[i], types[i] == mapServiceProvider, "mapServiceProvider");
  }

  Flickable {
    id: flicker

    anchors { fill: parent }
    contentHeight: col.height
    flickableDirection: Flickable.VerticalFlick
    boundsBehavior: Flickable.DragOverBounds

    Column {
      id: col
      spacing: 32
      width: parent.width

      Column {
        anchors.horizontalCenter: parent.horizontalCenter

        Label {
          text: qsTr("Map type")
          anchors.horizontalCenter: parent.horizontalCenter
        }

        ButtonColumn {
          id: mapTypes
          exclusive: true
          anchors.horizontalCenter: parent.horizontalCenter
        }
      }

      Column {
        anchors.horizontalCenter: parent.horizontalCenter

        Label {
          text: qsTr("Map service")
	  anchors.horizontalCenter: parent.horizontalCenter
        }

        ButtonColumn {
          id: mapServiceProviders
          exclusive: true
          anchors.horizontalCenter: parent.horizontalCenter
        }

        Label {
          width: parent.width
          anchors.left: parent.left
          text: qsTr("<small>A change of the map service takes effect after restart.</small>")
          wrapMode: Text.Wrap
        }
      }

      Column {
        width: parent.width
        anchors.horizontalCenter: parent.horizontalCenter

        Label {
          id: usernameLabel
          width: parent.width
          anchors.horizontalCenter: parent.horizontalCenter
          text: qsTr("Username:")
        }

        TextField {
           id: usernameEntry
           anchors.horizontalCenter: parent.horizontalCenter
           width: parent.width
	   height: 2*usernameLabel.height
	   text: "Hallo"
	   focus: true
         }
      }

      ComboButton {
        anchors.horizontalCenter: parent.horizontalCenter
	text: qsTr("ComboBox")
      }

    }
  }

  ToolBarLayout {
    id: backMenuTool
    visible: true
    ToolIcon { iconId: "toolbar-back"; onClicked: { setConfiguration(); pageStack.pop(); } }
  }

  Component.onCompleted: fillGroups();
}