#include <QDebug>
#include <QApplication>
#include <QDeclarativeEngine>
#include <QDeclarativeComponent>
#include <QDeclarativeContext>
#include <QDeclarativeView>
#include <QOrientationSensor>
#include <QDesktopWidget>
#include <QTranslator>
#include <QLocale>

#include "mapwidget.h"
#include "filefinder.h"
#include "system.h"

int main(int argc, char ** argv)
{
  QApplication app(argc, argv);

  QString locale = QLocale::system().name();
  QTranslator translator;

#ifdef LIBDIR
  // make sure the geoservice plugins in /usr/lib/cacheme/plugins
  // can be found
  app.addLibraryPath(QString(LIBDIR) + "/plugins");
#endif  

#ifdef DATADIR
  // try to load translation, first from local, then from DATADIR
  if(!translator.load(QString(APPNAME) + "_" + locale))
    translator.load(QString(APPNAME) + "_" + locale, 
                    QString(DATADIR) + "/lang");
#else
  translator.load(QString(APPNAME) + "_" + locale);
#endif
  
  app.installTranslator(&translator);
  
  // these values are important to store app settings
  app.setOrganizationName("Till Harbaum");
  app.setOrganizationDomain("harbaum.org");
  app.setApplicationName(APPNAME);

  qmlRegisterType<MapWidget>("MapWidget", 1, 0, "Map");

  QDeclarativeView view;
  QObject::connect((QObject*)view.engine(), SIGNAL(quit()), &app, SLOT(quit()));

  System system(&app);
  system.setupView(&view);

  view.rootContext()->setContextProperty("System", &system);

  view.setResizeMode(QDeclarativeView::SizeRootObjectToView);

  QString filename = FileFinder::find("qml", "main.qml");
  if(filename.isNull()) return -1;

  view.setSource(QUrl::fromLocalFile(filename));

#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
    view.showFullScreen();
#else
#if defined(Q_WS_MEEGO)
    view.setGeometry(QApplication::desktop()->screenGeometry());
    view.showFullScreen();
#else
    view.show();
#endif
#endif

  return app.exec();
}
