#include <QDebug>
#include <QSettings>

#include "filefinder.h"
#include "system.h"

#ifdef Q_WS_MAEMO_5
#include <QtGui/QX11Info>
#include <X11/Xlib.h>
#include <X11/Xatom.h>

static void grabZoomKeys(QWidget *window) {
  if(!window->winId()) return;
  
  unsigned long val = 1;
  Atom atom = XInternAtom(QX11Info::display(), "_HILDON_ZOOM_KEY_ATOM", False);
  if(!atom) return;
  
  XChangeProperty (QX11Info::display(), window->winId(), atom, 
                   XA_INTEGER, 32, PropModeReplace,
                   reinterpret_cast<unsigned char *>(&val),  1);
}
#endif

void System::setupView(QWidget *window) {
#ifdef Q_WS_MAEMO_5
  window->setAttribute(Qt::WA_Maemo5StackedWindow);
  window->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
  window->grabZoomKeys(this);
#endif
}

System::System(QObject *parent) :
  QObject(parent), m_locationProvider(NULL), m_cacheProvider(NULL),
  m_serviceProvider(NULL) {
  qDebug() << __FUNCTION__;

  setObjectName("System");

#ifdef Q_OS_SYMBIAN
    m_isSymbian = true;
#else
    m_isSymbian = false;
#endif

  // read service provider from settings as the map can't do that itself
  QSettings settings;
  settings.beginGroup("Map");
  m_serviceProviderName = settings.value("Service", "nokia").toString();
  settings.endGroup();

  m_serviceProvider = new QGeoServiceProvider(m_serviceProviderName);
  if(!m_serviceProvider->mappingManager()) {
    m_serviceProviderName = "nokia";
    m_serviceProvider = new QGeoServiceProvider(m_serviceProviderName);
  }

  m_locationProvider = new LocationProvider;

  m_cacheProvider = new CacheProvider;
}

System::~System() {
  qDebug() << __FUNCTION__;

  if(m_serviceProvider)
    delete m_serviceProvider;

  if(m_cacheProvider)
    delete m_cacheProvider;

  if(m_locationProvider)
    delete m_locationProvider;
}

QGeoMappingManager *System::mappingManager() const {
  if(m_serviceProvider)
    return m_serviceProvider->mappingManager();

  return NULL;
}

const QString System::versionString() {
  return VERSION;
}

bool System::osIsSymbian() const {
    return m_isSymbian;
}

bool System::osIsMeeGo() const {
  QFile file("/etc/issue");

  if(!file.exists()) return false;

  if(!file.open(QIODevice::ReadOnly | QIODevice::Text))
    return false;

  while (!file.atEnd())
    if(QString(file.readLine()).contains("meego", Qt::CaseInsensitive))
      return true;

  return false;
}

System *System::get() {
  return QCoreApplication::instance()->findChild<System*>("System");
}

LocationProvider *System::locationProvider() {
  return m_locationProvider;
}

CacheProvider *System::cacheProvider() {
  return m_cacheProvider;
}

const QString System::imagePath(const QString &file) {
  return FileFinder::find("icons", file);
}

void System::quit() const {
  QCoreApplication::instance()->quit();
}

QStringList System::availableGeoServiceProviders() const {
  return QGeoServiceProvider::availableServiceProviders();
}

QString System::currentGeoServiceProvider() const {
  return m_serviceProviderName;
}

void System::setGeoServiceProvider(const QString &name) const {
  QSettings settings;
  settings.beginGroup("Map");
  settings.setValue("Service", name);
  settings.endGroup();
}

QStringList System::availableCacheproviders() const {
  return m_cacheProvider->getPlugins();
}

QString System::currentCacheProvider() const {
  return m_cacheProvider->getCurrentPlugin();
}

void System::setCacheProvider(const QString &name) const {
  qDebug() << __FUNCTION__ << name;
  m_cacheProvider->select(name);
}
