#ifndef SYSTEM_H
#define SYSTEM_H

#include <QObject>
#include <QString>
#include <QStringList>
#include <QDeclarativeView>
#include <QCoreApplication>
#include <QGeoServiceProvider>

#include "locationprovider.h"
#include "cacheprovider.h"

class System : public QObject {
  Q_OBJECT

  Q_PROPERTY(bool isSymbian
	     READ osIsSymbian
	     NOTIFY osChanged)

public:
    explicit System(QObject *parent = 0);
    ~System();

    void setupView(QWidget *);
    bool osIsSymbian() const;
    bool osIsMeeGo() const;
    LocationProvider *locationProvider();
    CacheProvider *cacheProvider();
    static System *get();

    Q_INVOKABLE const QString versionString();
    Q_INVOKABLE const QString imagePath(const QString &);
    Q_INVOKABLE void quit() const;
    Q_INVOKABLE QGeoMappingManager *mappingManager() const;

    Q_INVOKABLE QStringList availableGeoServiceProviders() const;
    Q_INVOKABLE QString currentGeoServiceProvider() const;
    Q_INVOKABLE void setGeoServiceProvider(const QString &) const;

    Q_INVOKABLE QStringList availableCacheproviders() const;
    Q_INVOKABLE QString currentCacheProvider() const;
    Q_INVOKABLE void setCacheProvider(const QString &) const;

public slots:

private:
    bool m_isSymbian;
    LocationProvider *m_locationProvider;
    CacheProvider *m_cacheProvider;
    QGeoServiceProvider *m_serviceProvider;
    QString m_serviceProviderName;

signals:
    void osChanged();
    void zoomKeyEvent(bool up);
};

#endif // SYSTEM_H
